@@ -1,7 +1,7 @@
 //! Hash functions and hash utilities
 //!
 //! With the `fast-sha1` feature, the `Sha1` hash type will use a more elaborate implementation utilizing hardware support
-//! in case it is available. Otherwise the `sha1` feature should be set. `fast-sha1` will take precedence.
+//! in case it is available. Otherwise the `rustsha1` feature should be set. `fast-sha1` will take precedence.
 //! Otherwise, a minimal yet performant implementation is used instead for a decent trade-off between compile times and run-time performance.
 #[cfg(all(feature = "rustsha1", not(feature = "fast-sha1")))]
 mod _impl {
@@ -9,7 +9,7 @@ mod _impl {
 
     /// A implementation of the Sha1 hash, which can be used once.
     #[derive(Default, Clone)]
-    pub struct Sha1(rustsha1::Sha1);
+    pub struct Sha1(sha1_smol::Sha1);
 
     impl Sha1 {
         /// Digest the given `bytes`.
@@ -139,7 +139,7 @@ pub fn bytes(
         }
     }
 
-    let id = git_hash::ObjectId::new_sha1(hasher.digest());
+    let id = git_hash::ObjectId::from(hasher.digest());
     progress.show_throughput(start);
     Ok(id)
 }
@@ -176,8 +176,8 @@ mod write {
         T: std::io::Write,
     {
         /// Create a new hash writer which hashes all bytes written to `inner` with a hash of `kind`.
-        pub fn new(inner: T, kind: git_hash::Kind) -> Self {
-            match kind {
+        pub fn new(inner: T, object_hash: git_hash::Kind) -> Self {
+            match object_hash {
                 git_hash::Kind::Sha1 => Write {
                     inner,
                     hash: Sha1::default(),
