@@ -11,6 +11,8 @@
 
 ///
 pub mod cache;
+///
+pub mod decode;
 pub mod fs;
 pub mod hash;
 pub mod interrupt;
@@ -19,6 +21,7 @@ pub mod io;
 pub mod parallel;
 #[cfg(feature = "progress")]
 pub mod progress;
+pub mod threading;
 ///
 #[cfg(feature = "zlib")]
 pub mod zlib;
