@@ -35,11 +35,14 @@
 #[cfg(feature = "parallel")]
 mod in_parallel;
 #[cfg(feature = "parallel")]
-pub use in_parallel::{in_parallel, join};
+pub use in_parallel::{in_parallel, join, threads};
 
 mod serial;
 #[cfg(not(feature = "parallel"))]
-pub use serial::{in_parallel, join};
+pub use serial::{in_parallel, join, threads};
+
+mod in_order;
+pub use in_order::{InOrderIter, SequenceId};
 
 mod eager_iter;
 pub use eager_iter::{EagerIter, EagerIterIf};
@@ -111,7 +114,7 @@ pub fn optimize_chunk_size_and_thread_limit(
 
 /// Always returns 1, available when the `parallel` feature toggle is unset.
 #[cfg(not(feature = "parallel"))]
-fn num_threads(_thread_limit: Option<usize>) -> usize {
+pub fn num_threads(_thread_limit: Option<usize>) -> usize {
     1
 }
 
@@ -119,22 +122,23 @@ fn num_threads(_thread_limit: Option<usize>) -> usize {
 ///
 /// Only available with the `parallel` feature toggle set.
 #[cfg(feature = "parallel")]
-fn num_threads(thread_limit: Option<usize>) -> usize {
-    let logical_cores = || num_cpus::get();
+pub fn num_threads(thread_limit: Option<usize>) -> usize {
+    let logical_cores = num_cpus::get();
     thread_limit
-        .map(|l| if l == 0 { logical_cores() } else { l })
-        .unwrap_or_else(logical_cores)
+        .map(|l| if l == 0 { logical_cores } else { l })
+        .unwrap_or(logical_cores)
 }
 
 /// Run [`in_parallel()`] only if the given `condition()` returns true when eagerly evaluated.
 ///
 /// For parameters, see the documentation of [`in_parallel()`]
+#[cfg(feature = "parallel")]
 pub fn in_parallel_if<I, S, O, R>(
     condition: impl FnOnce() -> bool,
     input: impl Iterator<Item = I> + Send,
     thread_limit: Option<usize>,
-    new_thread_state: impl Fn(usize) -> S + Send + Sync,
-    consume: impl Fn(I, &mut S) -> O + Send + Sync,
+    new_thread_state: impl Fn(usize) -> S + Send + Clone,
+    consume: impl Fn(I, &mut S) -> O + Send + Clone,
     reducer: R,
 ) -> Result<<R as Reduce>::Output, <R as Reduce>::Error>
 where
@@ -149,6 +153,28 @@ where
     }
 }
 
+/// Run [`in_parallel()`] only if the given `condition()` returns true when eagerly evaluated.
+///
+/// For parameters, see the documentation of [`in_parallel()`]
+///
+/// Note that the non-parallel version is equivalent to [`in_parallel()`].
+#[cfg(not(feature = "parallel"))]
+pub fn in_parallel_if<I, S, O, R>(
+    _condition: impl FnOnce() -> bool,
+    input: impl Iterator<Item = I>,
+    thread_limit: Option<usize>,
+    new_thread_state: impl Fn(usize) -> S,
+    consume: impl Fn(I, &mut S) -> O,
+    reducer: R,
+) -> Result<<R as Reduce>::Output, <R as Reduce>::Error>
+where
+    R: Reduce<Input = O>,
+    I: Send,
+    O: Send,
+{
+    serial::in_parallel(input, thread_limit, new_thread_state, consume, reducer)
+}
+
 ///
 pub mod reduce;
 pub use reduce::Reduce;
