@@ -2,6 +2,7 @@
 use std::io;
 
 pub use prodash::{
+    messages::MessageLevel,
     progress::{Discard, DoOrDiscard, Either, ThroughputOnDrop},
     unit, Progress, Unit,
 };
@@ -35,35 +36,61 @@ pub fn steps() -> Option<Unit> {
 }
 
 /// A structure passing every [`read`][std::io::Read::read()] call through to the contained Progress instance using [`inc_by(bytes_read)`][Progress::inc_by()].
-pub struct Read<R, P> {
+pub struct Read<T, P> {
     /// The implementor of [`std::io::Read`] to which progress is added
-    pub reader: R,
+    pub inner: T,
     /// The progress instance receiving progress information on each invocation of `reader`
     pub progress: P,
 }
 
-impl<R, P> io::Read for Read<R, P>
+impl<T, P> io::Read for Read<T, P>
 where
-    R: io::Read,
+    T: io::Read,
     P: Progress,
 {
     fn read(&mut self, buf: &mut [u8]) -> io::Result<usize> {
-        let bytes_read = self.reader.read(buf)?;
+        let bytes_read = self.inner.read(buf)?;
         self.progress.inc_by(bytes_read as usize);
         Ok(bytes_read)
     }
 }
 
-impl<R, P> io::BufRead for Read<R, P>
+impl<T, P> io::BufRead for Read<T, P>
 where
-    R: io::BufRead,
+    T: io::BufRead,
     P: Progress,
 {
     fn fill_buf(&mut self) -> io::Result<&[u8]> {
-        self.reader.fill_buf()
+        self.inner.fill_buf()
     }
 
     fn consume(&mut self, amt: usize) {
-        self.reader.consume(amt)
+        self.inner.consume(amt)
+    }
+}
+
+/// A structure passing every [`write`][std::io::Write::write()] call through to the contained Progress instance using [`inc_by(bytes_written)`][Progress::inc_by()].
+///
+/// This is particularly useful if the final size of the bytes to write is known or can be estimated precisely enough.
+pub struct Write<T, P> {
+    /// The implementor of [`std::io::Write`] to which progress is added
+    pub inner: T,
+    /// The progress instance receiving progress information on each invocation of `reader`
+    pub progress: P,
+}
+
+impl<T, P> io::Write for Write<T, P>
+where
+    T: io::Write,
+    P: Progress,
+{
+    fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
+        let written = self.inner.write(buf)?;
+        self.progress.inc_by(written);
+        Ok(written)
+    }
+
+    fn flush(&mut self) -> io::Result<()> {
+        self.inner.flush()
     }
 }
